Plugin: JS9Colorbar

### JS9 Colorbar

The JS9 Colorbar displays the mapping of colors to pixel values for the currently displayed image. The choice of colormap and scale (including scale min and max values) determines the initial distribution of colors. Moving the mouse to changing the contrast/bias affects the mapping by expanding/compressing (contrast) and shifting (bias) the colormap so that it covers different ranges of image values.

If you change scales (e.g., from linear to log), the colormap at first might not appear to change. However, note that the numeric labels have changed. This shows you how colors are now associated with a different range of pixel values. The linear scale displays an evenly distributed range of image values, but the log scale does not: the distribution is a log(base10) distribution.

When printing an image using the File->print menu option, if a colorbar is active on the page, it will be placed beneath the image.